@@ -2,14 +2,19 @@
 
 import webview
 
+def on_before_show(window):
+    print('Native window object', window.native)
+
 
 def on_closed():
     print('pywebview window is closed')
 
-
 def on_closing():
     print('pywebview window is closing')
 
+def on_initialized(renderer):
+    # return False to cancel initialization
+    print(f'GUI is initialized with renderer: {renderer}')
 
 def on_shown():
     print('pywebview window shown')
@@ -35,12 +40,13 @@ def on_resized(width, height):
     )
 
 
-def on_loaded():
+# you can supply optional window argument to access the window object event was triggered on
+def on_loaded(window):
     print('DOM is ready')
 
     # unsubscribe event listener
-    webview.windows[0].events.loaded -= on_loaded
-    webview.windows[0].load_url('https://pywebview.flowrl.com/hello')
+    window.events.loaded -= on_loaded
+    window.load_url('https://pywebview.flowrl.com/hello')
 
 
 def on_moved(x, y):
@@ -54,6 +60,8 @@ if __name__ == '__main__':
 
     window.events.closed += on_closed
     window.events.closing += on_closing
+    window.events.before_show += on_before_show
+    window.events.initialized += on_initialized
     window.events.shown += on_shown
     window.events.loaded += on_loaded
     window.events.minimized += on_minimized
