@@ -1,8 +1,7 @@
 import webview
-import threading
 
 """
-This example demonstrates a difference between different link types
+Demonstrate a difference between different link types
 """
 
 
