@@ -27,4 +27,4 @@ class Api:
 if __name__ == '__main__':
     api = Api()
     webview.create_window('Todos magnificos', 'assets/index.html', js_api=api, min_size=(600, 450))
-    webview.start()
+    webview.start(ssl=True)
