@@ -1,10 +1,7 @@
-import webview
-import threading
-import time
+"""Switch application window to a full-screen mode after five seconds.."""
 
-"""
-This example demonstrates how to toggle fullscreen mode programmatically.
-"""
+import time
+import webview
 
 
 def toggle_fullscreen(window):
