@@ -1,21 +1,21 @@
 #!/bin/bash
 PYTHONPATH=..
 PYWEBVIEW_LOG='debug'
-PYTEST_OPTIONS='-s --disable-pytest-warnings -r w'
+PYTEST_OPTIONS='-q -s --disable-warnings -r w'
 
 # cd "${0%/*}"
 # rm -r __pycache__ || true
 
 exitcode=0
 pywebviewtest() {
-  python3 -m pytest "$@" || exitcode=$?
+  python3 -m pytest ${PYTEST_OPTIONS} "$@" || exitcode=$?
 }
 
 # cd ..
 echo Starting tests...
 for test in $(ls test_*); do
 echo $test
-  pywebviewtest $test ${PYTEST_OPTIONS}
+  pywebviewtest $test
 done
 
 if [ $exitcode != 0 ]; then
