@@ -7,23 +7,29 @@ from .util import assert_js, run_test
 
 def test_js_bridge():
     api = Api()
-    window = webview.create_window('JSBridge test', js_api=api)
+    window = webview.create_window('JSBridge test', html='<html><body>TEST</body></html>', js_api=api)
     run_test(webview, window, js_bridge)
 
 
 def test_exception():
     api = Api()
-    window = webview.create_window('JSBridge test', js_api=api)
+    window = webview.create_window('JSBridge test', html='<html><body>TEST</body></html>', js_api=api)
     run_test(webview, window, exception)
 
 
 # This test randomly fails on Windows
 def test_concurrent():
     api = Api()
-    window = webview.create_window('JSBridge test', js_api=api)
+    window = webview.create_window('JSBridge test', html='<html><body>TEST</body></html>', js_api=api)
     run_test(webview, window, concurrent)
 
 
+def test_skip_existing():
+    api = Api()
+    window = webview.create_window('JSBridge test', html='<html><body>TEST</body></html>', js_api=api)
+    run_test(webview, window, skip_existing)
+
+
 class NestedApi:
     @classmethod
     def get_int(cls):
@@ -38,6 +44,7 @@ class Api:
 
     nested = NestedApi
     nested_instance = NestedApi()
+    nested_instance_duplicate = nested_instance
 
     def get_int(self):
         return 420
@@ -71,7 +78,6 @@ class Api:
 
 
 def js_bridge(window):
-    window.load_html('<html><body>TEST</body></html>')
     assert_js(window, 'get_int', 420)
     assert_js(window, 'get_float', 3.141)
     assert_js(window, 'get_string', 'test')
@@ -98,3 +104,6 @@ def concurrent(window):
 
     for e in filter(lambda r: r, [f.exception() for f in futures]):
         raise e
+
+def skip_existing(window):
+    assert window.evaluate_js('window.pywebview.api.nested_instance_duplicate === undefined')
