@@ -1,4 +1,5 @@
 import webview
+
 from .util import run_test
 
 
@@ -8,7 +9,4 @@ def test_url_load():
 
 
 def url_load(window):
-    window.load_url('https://www.google.org')
-
-
-
+    window.load_url('https://pywebview.flowrl.com')
