@@ -3,6 +3,7 @@ import logging
 import os
 import shutil
 import sys
+from uuid import uuid4
 import webbrowser
 from copy import copy
 from ctypes import windll
@@ -12,9 +13,7 @@ from time import sleep
 
 from cefpython3 import cefpython as cef
 
-from webview import _settings, settings
-from webview.js import dom_json
-from webview.js.css import disable_text_select
+from webview import _state, settings
 from webview.util import DEFAULT_HTML, create_cookie, js_bridge_call, inject_pywebview
 
 sys.excepthook = cef.ExceptHook
@@ -24,6 +23,7 @@ logger = logging.getLogger(__name__)
 
 browser_settings = {}
 command_line_switches = {}
+renderer = 'cef'
 
 
 def _set_dpi_mode(enabled):
@@ -72,7 +72,6 @@ class JSBridge:
         js_bridge_call(self.window, func_name, json.loads(param), value_id)
 
 
-renderer = 'cef'
 
 
 class CookieVisitor:
@@ -102,7 +101,6 @@ class Browser:
         self.handle = handle
         self.browser = browser
         self.parent = parent
-        self.text_select = window.text_select
         self.uid = window.uid
         self.loaded = window.events.loaded
         self.shown = window.events.shown
@@ -119,16 +117,10 @@ class Browser:
         self.cookie_visitor = CookieVisitor()
 
         self.browser.GetJavascriptBindings().Rebind()
-        self.browser.ExecuteJavascript(inject_pywebview(self.window, 'cef'))
-
-        if not self.text_select:
-            self.browser.ExecuteJavascript(disable_text_select)
-
-        self.browser.ExecuteJavascript(dom_json.src)
+        inject_pywebview('cef', self.window)
 
         sleep(0.1)  # wait for window.pywebview to load
         self.initialized = True
-        self.loaded.set()
 
     def close(self):
         self.browser.CloseBrowser(True)
@@ -149,33 +141,36 @@ class Browser:
         )
         self.browser.NotifyMoveOrResizeStarted()
 
-    def evaluate_js(self, code, unique_id):
-        self.loaded.wait()
-
+    def evaluate_js(self, code, unique_id, parse_json):
         self.eval_events[unique_id] = Event()
-        eval_script = """
-            try {{
-                {0}
-            }} catch(e) {{
-                console.error(e.stack);
-                window.external.return_result(null, '{1}');
-            }}
-        """.format(
-            code, unique_id
-        )
 
-        result = self.browser.ExecuteJavascript(eval_script)
-        self.eval_events[unique_id].wait()  # result is obtained via JSBridge.return_result
+        if unique_id:
+            eval_script = f"""
+                try {{
+                    {code}
+                }} catch(e) {{
+                    window.external.return_result(null, '{unique_id}');
+                }}
+            """
 
-        result = copy(self.js_bridge.results[unique_id])
+            self.browser.ExecuteJavascript(eval_script)
+            self.eval_events[unique_id].wait()  # result is obtained via JSBridge.return_result
 
-        del self.eval_events[unique_id]
-        del self.js_bridge.results[unique_id]
+            result = copy(self.js_bridge.results[unique_id])
 
-        return result
+            del self.eval_events[unique_id]
+            del self.js_bridge.results[unique_id]
+
+            return result
+        else:
+            self.browser.ExecuteJavascript(code)
+            return None
+
+    def clear_cookies(self):
+        self.cookie_manager.DeleteCookies('', '')
+        self.cookie_manager.FlushStore()
 
     def get_cookies(self):
-        self.loaded.wait()
         self.cookie_visitor.cookies = []
         self.cookie_visitor.lock = Event()
         self.cookie_manager.VisitUrlCookies(self.browser.GetUrl(), True, self.cookie_visitor)
@@ -184,17 +179,14 @@ class Browser:
         return self.cookie_visitor.cookies
 
     def get_current_url(self):
-        self.loaded.wait()
         return self.browser.GetUrl()
 
     def load_url(self, url):
         self.initialized = False
-        self.loaded.clear()
         self.browser.LoadUrl(url)
 
     def load_html(self, html):
         self.initialized = False
-        self.loaded.clear()
         self.browser.LoadUrl('data:text/html,{0}'.format(html))
 
     def focus(self):
@@ -237,7 +229,7 @@ def _cef_call(func):
         uid = args[-1]
 
         if uid not in instances:
-            logger.error('CEF window with uid {0} does not exist'.format(uid))
+            logger.error(f'CEF window with uid {uid} does not exist with {func}')
             return
 
         return func(*args, **kwargs)
@@ -254,18 +246,18 @@ def init(_, cache_dir):
 
         default_settings = {
             'multi_threaded_message_loop': True,
-            'context_menu': {'enabled': _settings['debug']},
+            'context_menu': {'enabled': _state['debug']},
         }
 
         default_command_line_switches = {
             'enable-media-stream': '',
         }
 
-        if not _settings['debug']:
+        if not _state['debug']:
             default_settings['remote_debugging_port'] = -1
 
-        if _settings['user_agent']:
-            default_settings['user_agent'] = _settings['user_agent']
+        if _state['user_agent']:
+            default_settings['user_agent'] = _state['user_agent']
 
         if cache_dir:
             default_settings['cache_path'] = cache_dir
@@ -273,6 +265,9 @@ def init(_, cache_dir):
         if settings['ALLOW_FILE_URLS']:
             default_command_line_switches['allow-file-access-from-files'] = ''
 
+        if settings['IGNORE_SSL_ERRORS']:
+            default_command_line_switches['ignore-certificate-errors'] = ''
+
         resource_root = getattr(sys, '_MEIPASS', os.path.dirname(cef.__file__))
 
         default_settings.update(
@@ -318,7 +313,7 @@ def create_browser(window, handle, alert_func, parent):
         window.events.shown.set()
         cef_browser.SendFocusEvent(True)
 
-        if _settings['debug'] and settings['OPEN_DEVTOOLS_IN_DEBUG']:
+        if _state['debug'] and settings['OPEN_DEVTOOLS_IN_DEBUG']:
             cef_browser.ShowDevTools()
 
     window_info = cef.WindowInfo()
@@ -345,9 +340,15 @@ def load_url(url, uid):
 
 
 @_cef_call
-def evaluate_js(code, result, uid):
+def evaluate_js(code, unique_id, parse_json, uid):
     instance = instances[uid]
-    return instance.evaluate_js(code, result)
+    return instance.evaluate_js(code, unique_id, parse_json)
+
+
+@_cef_call
+def clear_cookies(uid):
+    instance = instances[uid]
+    return instance.clear_cookies()
 
 
 @_cef_call
@@ -388,7 +389,7 @@ def shutdown():
         if os.path.exists('webrtc_event_logs'):
             shutil.rmtree('webrtc_event_logs')
 
-        if os.path.exists('error.log') and not _settings['debug']:
+        if os.path.exists('error.log') and not _state['debug']:
             os.remove('error.log')
 
         if sys.platform == 'win32':
